ResponseData

Struct ResponseData 

pub struct ResponseData { /* private fields */ }

Implementations

Source

impl ResponseData

pub fn new( owner: BytesMut, dependent_builder: impl for<'_q> FnOnce(&'_q BytesMut) -> Response<'_q>, ) -> Self

Constructs a new self-referential struct.

The provided owner will be moved into a heap allocated box. Followed by construction of the dependent value, by calling dependent_builder with a shared reference to the owner that remains valid for the lifetime of the constructed struct.

pub fn try_new<Err>( owner: BytesMut, dependent_builder: impl for<'_q> FnOnce(&'_q BytesMut) -> Result<Response<'_q>, Err>, ) -> Result<Self, Err>

Constructs a new self-referential struct or returns an error.

Consumes owner on error.

pub fn try_new_or_recover<Err>( owner: BytesMut, dependent_builder: impl for<'_q> FnOnce(&'_q BytesMut) -> Result<Response<'_q>, Err>, ) -> Result<Self, (BytesMut, Err)>

Constructs a new self-referential struct or returns an error.

Returns owner and error as tuple on error.

pub fn borrow_owner<'_q>(&'_q self) -> &'_q BytesMut

Borrows owner.

pub fn with_dependent<'outer_fn, Ret>( &'outer_fn self, func: impl for<'_q> FnOnce(&'_q BytesMut, &'outer_fn Response<'_q>) -> Ret, ) -> Ret

Calls given closure func with a shared reference to dependent.

pub fn with_dependent_mut<'outer_fn, Ret>( &'outer_fn mut self, func: impl for<'_q> FnOnce(&'_q BytesMut, &'outer_fn mut Response<'_q>) -> Ret, ) -> Ret

Calls given closure func with an unique reference to dependent.

pub fn borrow_dependent<'_q>(&'_q self) -> &'_q Response<'_q>

Borrows dependent.

pub fn into_owner(self) -> BytesMut

Consumes self and returns the the owner.

Source

impl ResponseData

pub fn raw(&self) -> &[u8]

pub fn raw_str(&self) -> Option<&str>

pub fn request_id(&self) -> Option<&RequestId>

pub fn parsed(&self) -> &Response<'_>